/*********************************************************************
 *
 * File:         global.h
 *
 * Description:  Global definitions for conference engine
 *
 * Author:       Tomasz Stachowiak, NPAC
 *
 * Date:         10-14-96
 *
 *********************************************************************/
#include <stdio.h>
#include <stdlib.h>

#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <sys/time.h>

#include <netdb.h>
#include <unistd.h>

#define QUIET

#ifndef QUIET
#define PRINTF printf
#else
#define PRINTF nic 
#endif

#define MAX_UDP_SIZE 60000

#define MAX_MEMBERS 20
#define MAX_APPS 20

#define DAEMON_PORT 5000
#define MANAGER_PORT 4999
#define SERVER_PORT 4997

#define MSG_HEADER_LENGTH 56
#define MEMBER_LENGTH 25

typedef struct _participant
{
  unsigned char handle;
  char user[20];
  int host;
} Participant;

typedef struct _msg_header
{
  unsigned char tag;
  unsigned char session;
  Participant sender;
  Participant receiver;
  int dataLength;
} MsgHeader;

/* Tags in local messages */
typedef enum _local_tag
{
  /* local requests */
  reqLocalSessionCreate,          
  reqLocalSessionQuit,
  reqLocalSessionAddMember,
  reqLocalSessionJoin,
  reqLocalSessionReject,
  reqLocalSessionGetMembers,      
  reqLocalSessionSendToApp,
  reqLocalSessionStartApp,

  /* local indications */
  indLocalSessionInvited,
  indLocalSessionAccept,
  indLocalSessionReject,          
  indLocalSessionMembers,
  indLocalSessionAddMember,
  indLocalSessionDeleteMember,
  indLocalSessionLocalMember,
  indLocalSessionStartApp,
  indLocalSessionTimeout,
  indLocalSessionConnected,

  indLocalAppQuit
} LocalTag;

typedef enum _member_tag
{
  /* remote requests */
  reqRemoteSessionAccept,
  reqRemoteSessionQuit,
  reqRemoteSessionReject,
  reqRemoteSessionAddMember,
  reqRemoteSessionAddRest,
  reqRemoteSessionSendToApp,
  reqRemoteSessionSendAppData,
  reqRemoteSessionStartApp,

  /* remote acknowledgments */
  ackRemoteInvitationReceived
} MemberTag;

typedef enum _app_tag
{
  reqAppDettach=50,
  reqAppData,
  indAppData
} AppTag;

typedef enum _new_tag
{
  reqNewLocalSessionInit=60,
  reqNewRemoteSessionConnect,
  reqNewRemoteSessionInvite,
  reqNewLocalApplicationAttach
} NewTag;

typedef enum _server_tag
{
  reqServerAddUser=100,
  reqServerDelUser,
  reqServerUsers,
  indServerUsers
} ServerTag;

typedef struct _NCS_participant
{
  char user[20];
  char host[50];
} NCSparticipant;

typedef struct _server_data
{
  int numMembers;
  Participant parts[1];
} ServerData;


typedef struct _member_info
{
  int handle;
  Participant part;
  struct sockaddr_in addr;
} MemberInfo;

typedef struct _app_data
{
  unsigned char handle;
  int recID;
  int port;
  short tag;
  char data[1];
} AppData;

#define LOCAL 1
#define REMOTE 0

int sendControlMessage(int sock, MsgHeader *header, char *msg, int len);
